@@ -98,6 +98,10 @@ public:
 
   bool create_table(const sharedptr<const TableInfo>& table_info, const Document_Glom::type_vecFields& fields) const;
   bool create_table_add_missing_fields(const sharedptr<const TableInfo>& table_info, const Document_Glom::type_vecFields& fields) const;
+
+  /// Also saves the table information in the document:
+  bool create_table_with_default_fields(const Glib::ustring& table_name);
+
   bool insert_example_data(const Glib::ustring& table_name) const;
 
   typedef std::vector< sharedptr<LayoutItem_Field> > type_vecLayoutFields;
@@ -120,6 +124,7 @@ protected:
   type_vecStrings get_table_names_from_database(bool ignore_system_tables = false) const;
 
   bool get_table_exists_in_database(const Glib::ustring& table_name) const;
+  bool get_relationship_exists(const Glib::ustring& table_name, const Glib::ustring& relationship_name);
 
   type_vecFields get_fields_for_table(const Glib::ustring& table_name, bool including_system_fields = false) const;
   sharedptr<Field> get_fields_for_table_one_field(const Glib::ustring& table_name, const Glib::ustring& field_name) const;
