@@ -371,7 +371,10 @@ Utils::type_list_values_with_second Utils::get_choice_values(const sharedptr<con
   Glib::ustring choice_field, choice_second;
   field->get_formatting_used().get_choices(choice_relationship, choice_field, choice_second);
   if(!choice_relationship)
+  {
+    //std::cout <<" debug: field has no choices: " << field->get_name() << std::endl;
     return list_values;
+  }
 
   const Glib::ustring to_table = choice_relationship->get_to_table();
   if(to_table.empty())
@@ -390,6 +393,7 @@ Utils::type_list_values_with_second Utils::get_choice_values(const sharedptr<con
 
   sql_query += " FROM \"" + choice_relationship->get_to_table() + "\" ORDER BY \"" + to_table + "\".\"" + choice_field + "\"";
 
+  //std::cout << "debug: get_choice_values(): query: " << sql_query << std::endl;
   //Connect to database:
   sharedptr<SharedConnection> connection = ConnectionPool::get_instance()->connect();
 
@@ -399,14 +403,15 @@ Utils::type_list_values_with_second Utils::get_choice_values(const sharedptr<con
 
   if(datamodel)
   {
-    guint count = datamodel->get_n_rows();
+    const guint count = datamodel->get_n_rows();
+    //std::cout << "  result: count=" << count << std::endl;
     for(guint row = 0; row < count; ++row)
     {
       std::pair<Gnome::Gda::Value, Gnome::Gda::Value> itempair;
       itempair.first = datamodel->get_value_at(0, row);
 
       if(with_second)
-        itempair.second = datamodel->get_value_at(1, row);
+			itempair.second = datamodel->get_value_at(1, row);
 
       list_values.push_back(itempair);
     }
@@ -580,6 +585,8 @@ Glib::ustring Utils::title_from_string(const Glib::ustring& text)
 
 Utils::type_vecStrings Utils::string_separate(const Glib::ustring& str, const Glib::ustring& separator, bool ignore_quoted_separator)
 {
+  //std::cout << "Utils::string_separate(): separator=" << separator << std::endl;
+
   type_vecStrings result;
 
   const Glib::ustring::size_type size = str.size();
@@ -680,7 +687,7 @@ Utils::type_vecStrings Utils::string_separate(const Glib::ustring& str, const Gl
 
         //Store this item, and start the next item after it:
         item = str.substr(item_start, posComma - item_start);
-        //std::cout << "ITEM. pos_comma=" << posComma << ", ITEM= " << item << std::endl;
+        //std::cout << "  ITEM. pos_comma=" << posComma << ", ITEM= " << item << std::endl;
 	item_start = posComma + size_separator;
       }
       //else
@@ -709,21 +716,42 @@ Glib::ustring Utils::string_trim(const Glib::ustring& str, const Glib::ustring&
    Glib::ustring::size_type posOpenBracket = result.find(to_remove);
    if(posOpenBracket == 0)
    {
-//g_warning("string_trim: before start trim: %s", result.c_str());
       result = result.substr(to_remove.size());
-//g_warning("string_trim: after start trim: %s", result.c_str());
    }
 
    //Remove from the end:
    Glib::ustring::size_type posCloseBracket = result.rfind(to_remove);
    if(posCloseBracket == (result.size() - to_remove.size()))
    {
-     //g_warning("string_trim: before end trim: %s", result.c_str());
     result = result.substr(0, posCloseBracket);
-     //g_warning("string_trim: after end trim: %s", result.c_str());
    }
 
   return result;
 }
 
+Glib::ustring Utils::string_remove_suffix(const Glib::ustring& str, const Glib::ustring& suffix, bool case_sensitive)
+{
+  //There is also g_string_has_suffix(), but I assume that is case sensitive. murrayc.
+
+  const Glib::ustring::size_type size = str.size();
+  const Glib::ustring::size_type suffix_size = suffix.size();
+  if(size < suffix_size)
+    return str;
+
+  const Glib::ustring possible_suffix = str.substr(size - suffix_size);
+
+  if(case_sensitive)
+  {
+    if(possible_suffix == suffix)
+      return str.substr(0, size - suffix_size);
+  }
+  else
+  {
+    if(g_ascii_strcasecmp(possible_suffix.c_str(), suffix.c_str()) == 0) //TODO: I don't understand the warnings about using this function in the glib documentation. murrayc.
+      return str.substr(0, size - suffix_size);
+  }
+
+  return str;
+}
+
 } //namespace Glom
