@@ -21,6 +21,7 @@
 #include "box_data_list_related.h"
 #include "dialog_layout_list_related.h"
 #include <glom/libglom/data_structure/glomconversions.h>
+#include <glom/frame_glom.h> //For show_ok_dialog()
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
 #include <glibmm/i18n.h>
 
@@ -402,7 +403,7 @@ void Box_Data_List_Related::on_adddel_user_requested_add()
     Box_Data_List::on_adddel_user_requested_add();
 }
 
-sharedptr<const LayoutItem_Field> Box_Data_List_Related::get_field_identifies_non_hidden_related_record() const
+sharedptr<const LayoutItem_Field> Box_Data_List_Related::get_field_identifies_non_hidden_related_record(sharedptr<const Relationship>& used_in_relationship) const
 {
   //Find the first field that is from a non-hidden related table.
   sharedptr<LayoutItem_Field> result;
@@ -423,7 +424,10 @@ sharedptr<const LayoutItem_Field> Box_Data_List_Related::get_field_identifies_no
         if(!(table_name.empty()))
         {
           if(!(document->get_table_is_hidden(table_name)))
+          {
+            used_in_relationship = relationship;
             return field;
+          }
         }
       }
     }
@@ -477,7 +481,8 @@ bool Box_Data_List_Related::get_has_suitable_record_to_view_details() const
       return true;
     else
     {
-      sharedptr<const LayoutItem_Field> field = get_field_identifies_non_hidden_related_record();
+      sharedptr<const Relationship> used_in_relationship;
+      sharedptr<const LayoutItem_Field> field = get_field_identifies_non_hidden_related_record(used_in_relationship);
       if(field)
        return true;
     }
@@ -498,13 +503,31 @@ void Box_Data_List_Related::get_suitable_record_to_view_details(const Gnome::Gda
 
   if(!(document->get_table_is_hidden(LayoutWidgetBase::m_table_name)))
   {
+    //Non-hidden tables can just be shown directly. Navigate to it: 
     table_name = LayoutWidgetBase::m_table_name;
     table_primary_key_value = primary_key_value;
   }
   else
   {
-    //Find a suitable related table by finding the first layout field that mentions one:
+    //For hidden tables, find a suitable related non-hidden table by finding the first layout field that mentions one:
     sharedptr<const LayoutItem_Field> field = get_field_is_from_non_hidden_related_record();
+    if(!field)
+    {
+      //Instead, find a key field that's used in a relationship, and pretend that we are showing the to field as a related field:
+      sharedptr<const Relationship> used_in_relationship;
+      sharedptr<const LayoutItem_Field> field_identifies = get_field_identifies_non_hidden_related_record(used_in_relationship);
+      if(field_identifies && used_in_relationship)
+      {
+          sharedptr<LayoutItem_Field> fake_item = sharedptr<LayoutItem_Field>::create();
+          fake_item->set_relationship( glom_sharedptr_clone(used_in_relationship) ); //Clone to avoid the const.
+
+          fake_item->set_name(used_in_relationship->get_to_field());
+          fill_full_field_details(LayoutWidgetBase::m_table_name, fake_item);
+          field = fake_item;
+      }
+    }
+
+    //Get the value of the to field:
     if(field)
     {
       table_name = field->get_table_used(LayoutWidgetBase::m_table_name);
@@ -526,25 +549,38 @@ void Box_Data_List_Related::get_suitable_record_to_view_details(const Gnome::Gda
 
         const Glib::ustring query = Utils::build_sql_select_with_key(LayoutWidgetBase::m_table_name, fieldsToGet, m_AddDel.get_key_field(), primary_key_value);
         Glib::RefPtr<Gnome::Gda::DataModel> data_model = query_execute(query);
+
+        bool value_found = true;
         if(data_model && data_model->get_n_rows() && data_model->get_n_columns())
         {
           table_primary_key_value = data_model->get_value_at(0, 0);
           //std::cout << "Box_Data_List_Related::get_suitable_record_to_view_details(): table_primary_key_value=" << table_primary_key_value.to_string() << std::endl;
+
+          //The value is empty when there there is no record to match the key in the related table:
+          //For instance, if an invoice lines record mentions a product id, but the product does not exist in the products table.
+          if(Conversions::value_is_empty(table_primary_key_value))
+          {
+            value_found = false;
+            std::cout << "debug: Box_Data_List_Related::get_suitable_record_to_view_details(): SQL query returned empty primary key." << std::endl;
+          }
         }
         else
         {
-           std::cout << "Box_Data_List_Related::get_suitable_record_to_view_details(): SQL query returned no suitable primary key" << std::endl;
+           value_found = false;
+           std::cout << "debug: Box_Data_List_Related::get_suitable_record_to_view_details(): SQL query returned no suitable primary key." << std::endl;
+        }
+
+        if(!value_found)
+        {
+           Gtk::Window* window = get_app_window();
+           if(window)
+             Frame_Glom::show_ok_dialog(_("No Corresponding Record Exists"), _("No record with this value exists. Therefore navigation to the related record is not possible."), *window, Gtk::MESSAGE_WARNING); //TODO: Make it more clear to the user exactly what record, what field, and what value, we are talking about.
         }
       }
     }
     else
     {
-       sharedptr<const LayoutItem_Field> field = get_field_identifies_non_hidden_related_record();
-       if(field)
-       {
-         //TODO: We need the relationship, and we need to worry about doubly-related fields.
-         //table_name = field->get_table_used();
-       }
+      //TODO: We need to worry about doubly-related fields.
     }
 
   }
