@@ -24,6 +24,9 @@
 #include "box_data_list.h"
 #include "../utility_widgets/layoutwidgetbase.h"
 
+namespace Glom
+{
+
 class Dialog_Layout_List_Related;
 
 class Box_Data_List_Related : 
@@ -64,7 +67,7 @@ protected:
   virtual type_vecLayoutFields get_fields_to_show() const; //override
 
   sharedptr<const LayoutItem_Field> get_field_is_from_non_hidden_related_record() const;
-  sharedptr<const LayoutItem_Field> get_field_identifies_non_hidden_related_record() const;
+  sharedptr<const LayoutItem_Field> get_field_identifies_non_hidden_related_record(sharedptr<const Relationship>& used_in_relationship) const;
 
   virtual void on_adddel_user_requested_add();
   virtual void on_adddel_user_changed(const Gtk::TreeModel::iterator& row, guint col);
@@ -88,4 +91,6 @@ protected:
   type_signal_record_changed m_signal_record_changed;
 };
 
+} //namespace Glom
+
 #endif
