@@ -26,6 +26,9 @@
 #include <glom/libglom/utils.h>
 
 
+namespace Glom
+{
+
 DbTreeModelRow::DbTreeModelRow()
 : m_values_retrieved(false),
   m_removed(false),
@@ -207,10 +210,18 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
 
   if(m_connection && !m_found_set.m_table_name.empty() && m_get_records)
   {
-    const Glib::ustring sql_query = GlomUtils::build_sql_select_with_where_clause(m_found_set.m_table_name, m_column_fields, m_found_set.m_where_clause, m_found_set.m_sort_clause);
+    const Glib::ustring sql_query = Utils::build_sql_select_with_where_clause(m_found_set.m_table_name, m_column_fields, m_found_set.m_where_clause, m_found_set.m_sort_clause);
 
     //std::cout << "DbTreeModel: Executing SQL: " << sql_query << std::endl << std::endl;
-    m_gda_datamodel = m_connection->get_gda_connection()->execute_single_command(sql_query);
+    try
+    {
+      m_gda_datamodel = m_connection->get_gda_connection()->execute_single_command(sql_query);
+    }
+    catch(const std::exception& ex)
+    {
+      m_gda_datamodel.clear(); //So that it is 0, so we can handle it below.
+    }
+
     if(!m_gda_datamodel)
     {
       m_data_model_rows_count = 0;
@@ -883,3 +894,5 @@ void DbTreeModel::get_record_counts(gulong& total, gulong& found) const
     found = 0;
   }
 }
+
+} //namespace Glom
