@@ -26,6 +26,9 @@
 
 #include <iostream>   // for cout, endl
 
+namespace Glom
+{
+
 //JPEG seems to give ugly results when saved to the database and shown again.
 //#define GLOM_IMAGE_FORMAT "jpeg"
 //#define GLOM_IMAGE_FORMAT_MIME_TYPE "image/jpeg"
@@ -303,7 +306,7 @@ Gnome::Gda::Value ImageGlom::get_value() const
 
       //libgda currently assumes that this buffer is an already-escaped string.
       //TODO: Just use the raw buffer when libgda (in libgda-2.0) has been fixed:
-      Glib::ustring binary_escaped = GlomConversions::get_escaped_binary_data((guint8*)buffer, buffer_size);
+      Glib::ustring binary_escaped = Conversions::get_escaped_binary_data((guint8*)buffer, buffer_size);
       result.set(binary_escaped.c_str(), binary_escaped.size());
 
       g_free(buffer);
@@ -618,3 +621,5 @@ void ImageGlom::set_read_only(bool read_only)
   m_read_only = read_only;
 }
 
+
+} //namespace Glom
